@@ -4,10 +4,10 @@ import shutil
 import subprocess as sp
 
 # Args
-parser = argparse.ArgumentParser(description='Creates a conda environment from file for a given Python version.')
-parser.add_argument('-n', '--name', type=str, nargs=1, help='The name of the created Python environment')
-parser.add_argument('-p', '--python', type=str, nargs=1, help='The version of the created Python environment')
-parser.add_argument('conda_file', nargs='*', help='The file for the created Python environment')
+parser = argparse.ArgumentParser(description="Creates a conda environment from file for a given Python version.")
+parser.add_argument("-n", "--name", type=str, nargs=1, help="The name of the created Python environment")
+parser.add_argument("-p", "--python", type=str, nargs=1, help="The version of the created Python environment")
+parser.add_argument("conda_file", nargs="*", help="The file for the created Python environment")
 
 args = parser.parse_args()
 
