@@ -158,7 +158,10 @@ def test_pubchem_multiout_g():
             qcelemental.molparse.from_string(subject, return_processed=True)
     except qcelemental.ChoicesError as e:
         assert e.choices[10789] == "2-hydroxycyclohepta-2,4,6-trien-1-one"
-        assert e.choices[193687] == "2-hydroxy-3-iodo-6-propan-2-ylcyclohepta-2,4,6-trien-1-one"
+        # NOTE: 193687 no longer returned by PubChem. Adding a new choice
+        # this is a brittle test due to changes on PubChem's end.
+        # assert e.choices[193687] == "2-hydroxy-3-iodo-6-propan-2-ylcyclohepta-2,4,6-trien-1-one"
+        assert e.choices[85783535] == "(4-hydroxy-5-oxocyclohepta-1,3,6-trien-1-yl) dodecanoate"
 
 
 subject13 = """pubchem :ammonium\n"""
